@@ -40,6 +40,24 @@ def check_bucket(bucket):
             print(error)
     return check
 
+def list_objects(bucket):
+    """
+    """
+    keys = []
+    s3 = get_resource()
+    kwargs = {'Bucket': bucket}
+    while True:
+        resp = s3.meta.client.list_objects_v2(**kwargs)
+        for obj in resp['Contents']:
+            keys.append(obj['Key'])
+
+        try:
+            kwargs['ContinuationToken'] = resp['NextContinuationToken']
+        except KeyError:
+            break
+
+    return keys
+
 def get_resource():
     """
     @doc: create a boto3 session
