@@ -49,19 +49,6 @@ SET_TYPES = ['X_train', 'y_train', 'X_test', 'y_test', 'X_validate', 'y_validate
 
 CACHE_SIZE = 8
 
-def are_you_sure(name):
-    """
-    @doc: Get user input about whether or not to delete a project
-    @args: name is a str for the project name (corresponds to a directory)
-    @return: user input str ('yes' | 'no')
-    """
-    message = """Enter 'yes' (no quotes) to proceed with deleting the {} project
-    and starting over, and 'no' to keep the existing project:   
-    """.format(name)
-
-    ret = input(message)
-    return ret
-
 def print_line(line):
     """
     @doc: print information about a particular model run
@@ -70,7 +57,7 @@ def print_line(line):
     """
     ret = "|"
     for key in line.keys():
-        key_len = len(line[key])
+        key_len = len(str(line[key]))
         col_len = LINE_ATTR[key]
         if key_len > (col_len - 2):
             line[key] = line[key][:col_len - 2]
